@@ -135,8 +135,11 @@ public:
 
 public Q_SLOTS:
     void start();
+    void start(const QString &command);
     void abort();
 
+    static bool startDetached(const QString &command);
+
 Q_SIGNALS:
     void commandChanged();
     void workingDirectoryChanged();
